rapidity_from_beta

Function rapidity_from_beta 

pub fn rapidity_from_beta(beta: f64) -> Option<f64>
Computes rapidity φ = atanh(β) from a signed beta.

Returns None when beta is not finite, has an absolute value greater than or equal to 1.0, or when the computed rapidity is not finite.