pub fn beta(speed: f64) -> Option<f64>Expand description
Computes the dimensionless speed ratio β = v / c.
The speed input is treated as a magnitude in meters per second.
Returns None when speed is negative, not finite, greater than or equal to the speed of
light, or when the computed ratio is not finite.
Examples
use use_relativity::{SPEED_OF_LIGHT, beta};
assert_eq!(beta(SPEED_OF_LIGHT * 0.5), Some(0.5));